Class: SwaggerClient::Group
- Inherits:
-
Object
- Object
- SwaggerClient::Group
- Defined in:
- lib/api_gen/lib/swagger_client/models/group.rb
Overview
Группа студента
Instance Attribute Summary collapse
-
#current_course ⇒ Object
Номер курса.
-
#end_year ⇒ Object
Returns the value of attribute end_year.
-
#id ⇒ Object
Returns the value of attribute id.
-
#start_year ⇒ Object
Returns the value of attribute start_year.
-
#title ⇒ Object
Returns the value of attribute title.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Group
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Group
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 53 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'title') self.title = attributes[:'title'] end if attributes.has_key?(:'start_year') self.start_year = attributes[:'start_year'] end if attributes.has_key?(:'end_year') self.end_year = attributes[:'end_year'] end if attributes.has_key?(:'current_course') self.current_course = attributes[:'current_course'] end end |
Instance Attribute Details
#current_course ⇒ Object
Номер курса
27 28 29 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 27 def current_course @current_course end |
#end_year ⇒ Object
Returns the value of attribute end_year.
24 25 26 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 24 def end_year @end_year end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 18 def id @id end |
#start_year ⇒ Object
Returns the value of attribute start_year.
22 23 24 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 22 def start_year @start_year end |
#title ⇒ Object
Returns the value of attribute title.
20 21 22 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 20 def title @title end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 30 def self.attribute_map { :'id' => :'id', :'title' => :'title', :'start_year' => :'start_year', :'end_year' => :'end_year', :'current_course' => :'current_course' } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 41 def self.swagger_types { :'id' => :'Integer', :'title' => :'String', :'start_year' => :'Integer', :'end_year' => :'Integer', :'current_course' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
176 177 178 179 180 181 182 183 184 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 176 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && title == o.title && start_year == o.start_year && end_year == o.end_year && current_course == o.current_course end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 222 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = SwaggerClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 288 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 201 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
188 189 190 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 188 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
194 195 196 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 194 def hash [id, title, start_year, end_year, current_course].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 82 def list_invalid_properties invalid_properties = Array.new if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end if @title.to_s.length > 50 invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 50.') end if @title.to_s.length < 1 invalid_properties.push('invalid value for "title", the character length must be great than or equal to 1.') end if !@start_year.nil? && @start_year > 2147483647 invalid_properties.push('invalid value for "start_year", must be smaller than or equal to 2147483647.') end if !@start_year.nil? && @start_year < -2147483648 invalid_properties.push('invalid value for "start_year", must be greater than or equal to -2147483648.') end if !@end_year.nil? && @end_year > 2147483647 invalid_properties.push('invalid value for "end_year", must be smaller than or equal to 2147483647.') end if !@end_year.nil? && @end_year < -2147483648 invalid_properties.push('invalid value for "end_year", must be greater than or equal to -2147483648.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
268 269 270 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 268 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
274 275 276 277 278 279 280 281 282 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 274 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
262 263 264 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 262 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
117 118 119 120 121 122 123 124 125 126 |
# File 'lib/api_gen/lib/swagger_client/models/group.rb', line 117 def valid? return false if @title.nil? return false if @title.to_s.length > 50 return false if @title.to_s.length < 1 return false if !@start_year.nil? && @start_year > 2147483647 return false if !@start_year.nil? && @start_year < -2147483648 return false if !@end_year.nil? && @end_year > 2147483647 return false if !@end_year.nil? && @end_year < -2147483648 true end |